/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

#ifndef PULSAR_PRODUCER_STATS_BASE_HEADER
#define PULSAR_PRODUCER_STATS_BASE_HEADER
#include <pulsar/Message.h>
#include <pulsar/Result.h>

#include "lib/TimeUtils.h"

namespace pulsar {
class ProducerStatsBase {
   public:
    virtual void start() {}
    virtual void messageSent(const Message& msg) = 0;
    virtual void messageReceived(Result, const ptime&) = 0;
    virtual ~ProducerStatsBase(){};
};

typedef std::shared_ptr<ProducerStatsBase> ProducerStatsBasePtr;
}  // namespace pulsar

#endif  // PULSAR_PRODUCER_STATS_BASE_HEADER
